/*******************************************************************************
* Device      : AD122
* Author      :
* Version     : V1.0.0
* Date        : 2023.11.24
* Description : 演示进入PWOFF低功耗模式，并通过外部中断引脚进行唤醒的功能。
*               进入PWOFF模式之前，IO口PB2进行一定次数翻转，进入PWOFF模式睡眠后，IO口PB2停止翻转；
*				通过给配置的外部中断引脚PA2或PA0或PB0输入方波，会在IO的对应变化沿处唤醒，唤醒后IO口PB2会再次进行一定次数翻转后进入睡眠。
********************************************************************************/
#include "AD122.h"
#include <stdio.h>

/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1     :  内部时钟分频选择
* _DBG_OFF          :  禁用DEBUG模式（使能后DEBUG 口不能做普通IO用）
* _LVREN_OFF        :  LVR使能位
* _LVR24V           :  选择LVR电压为2.4V
* _FLASH_CP1_OFF    :  1K~2K*16 FLASH保护位
* _FLASH_CP0_OFF    :  0~1K*16 FLASH保护位
* _IDIS_OFF	     	:  模拟IO打开，数据读取控制位
* _CKSUM_OFF        :  使能程序校验
* _CBP_OFF			:  代码保护选择位
* _RESETE_OFF       :  禁用外部复位
* _RSEL_LOW		    :  端口上下拉电阻选择
* _STV_ON		    :  堆栈溢出复位使能位
* _PSUT_2		    :  上电复位时间选择位
* _FCPU_4T          :  选择指令周期为4T模式
* _WDTE_OFF         :  看门狗使能位
* _TWDT_000         :  看门狗溢出时间选择位
* _OSCM_HIRC_16M    :  选择内部高速时钟16MHz
* _MTPDIS_OFF       ： SWD模式下读FLASH和EEPROM控位
* _ADCSP_ON			:  ADC采集速度选择位
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _DBG_OFF_1L       & _LVREN_OFF_1L     & _LVR24V_1L                                                  );
__CONFIG(2,_FLASH_CP1_OFF_2L    & _FLASH_CP0_OFF_2L & _IDIS_OFF_2L      & _CKSUM_OFF_2L  & _CBP_OFF_2L   & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_2_3L           & _FCPU_4T_3L       & _WDTE_OFF_3L     & _TWDT_100_3L                                                );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _MTPDIS_OFF_4L    & _ADCSP_ON_4L                                                                                     );

#define SLEEP_PWIDLE() 		SMCR = 0X01; SLEEP();NOP();NOP()
#define SLEEP_PWSAVE() 		SMCR = 0X03; SLEEP();NOP();NOP()
#define SLEEP_DEEPPWSAVE()  SMCR = 0X05; SLEEP();NOP();NOP()
#define SLEEP_PWOFF() 		SMCR = 0X07; SLEEP();NOP();NOP()

void main(void)
{
	unsigned char i;

    CLKCFG1=0X00;    //关闭时钟

    IPEN=1;//允许高低优先级中断
	GIEH=1;//使能高优先级中断
	GIEL=1;//使能低优先级中断
	//PA2
	INT0IP=1;
	INT0IF=0;
	INT0IE=1;
	INT0EDGE=0;//0——上升沿触发中断  1——下降沿中断
	//PA0
	INT1IP=1;
	INT1IF=0;
	INT1IE=1;
	INT1EDGE=0;//0——上升沿触发中断  1——下降沿中断
	//PB0
	INT2IP=1;
	INT2IF=0;
	INT2IE=1;
	INT2EDGE=1;//0——上升沿触发中断  1——下降沿中断

	TRISA=0X05;//PA2，PA0设为输入模式
	TRISB=0X01;//PB0设为输入模式 PB2设为输出模式

	while(1)
	{
		for(i=0;i<100;i++)
		{
			PB2=~PB2;
			__delay_us(5000);
		}
		PB2=0;

		//SLEEP_PWIDLE();
		//SLEEP_PWSAVE();
		//SLEEP_DEEPPWSAVE();
		SLEEP_PWOFF();	//进入pwoff低功耗模式
	}
}


//中断服务函数
void __interrupt(high_priority) ISR_h(void)
{
	unsigned char tmp_int;
    tmp_int = PIR2;

	if((tmp_int&0X04)==0X04)
	{
		INT0IF=0;
	}
	if((tmp_int&0X08)==0X08)
	{
		INT1IF=0;
	}
	if((tmp_int&0X10)==0X10)
	{
		INT2IF=0;
	}
}

//低优先级中断服务函数

void interrupt low_priority ISR_l (void)
{


}


